# _*_ coding: utf-8_*_
"""
Author       : sliatecinos
Created Time : 2021-01-19 21:59:00
Updated Time : 2021-02-11 02:00:00
BR Registrations
environments:

"""
__version__ = '0.0.0.8'
